using BPA.SAAS.Manage.Application.Device.Dtos.DeviceVesion;
using BPA.SAAS.Manage.Core.Base;
using BPA.SAAS.Manage.Core.Product;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace BPA.SAAS.Manage.Application.Device.Interface
{
    public interface IDeviceVesionService
    {
        Task<PageUtil> GetDeviceVesionPageAsync(DeviceVesionQueryInputDto inputDto);
        Task<bool> AddDeviceVesionAsync(DeviceVesionBaseDto inputDto);
        Task<bool> DelDeviceVesionAsync(List<string> inputList);
        Task<bool> UpdateDeviceVesionAsync(DeviceVesionBaseDto inputDto);
        Task<bool> UpdateDeviceVesionSatatus(DeviceVesionSatatusDto inputDto);
        Task<List<BPA_ProductVesion>> GetDeviceVesion(string ProductId);
        Task<List<BPA_ProductVesion>> GetDeviceVesionList();
    }
}
